# aiomax

Асинхронный фреймворк [Max](https://max.ru) Bot API.

## Преимущества

- Полная асинхронность

- Возможность разделения на роутеры

- Эквиваленты всех функций доступных в Max Bot API

- Встроенный конечный автомат (FSM)

- Поддержка [PyPy](https://pypy.org/)
